.. FAME documentation master file, created by
   sphinx-quickstart on Sat Nov  9 18:22:23 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

FAME documentation
==================

Framework for Additive Manufacturing Emulation (FAME) is a `Python package <https://github.com/neoceph/FAME>`_ for the design and analysis of experiments in additive manufacturing. It is designed to be a flexible and extensible tool for researchers and practitioners in the field of additive manufacturing. FAME is developed using python with the help of other popular scientific libraries such as `VTK <https://github.com/Kitware/VTK>`_, `PETSc <https://github.com/petsc/petsc>`_, and `JAX <https://github.com/jax-ml/jax>`_. In addition to exploring conventional forward solving methodologies, this framework aims to integrate machine learning/deep learning to solve inverse problems in additive manufacturing.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Theories <theories/heatDiffusion.rst>
   Codebase <modules>
